import * as process from 'process';
import { moduleExists } from '@sweet-milktea/utils';
const isDevelopment = process.env.NODE_ENV === 'development';
/* 默认加载的插件 */
export const defaultPlugins = [
    '@babel/plugin-proposal-async-do-expressions',
    ['@babel/plugin-proposal-decorators', { decoratorsBeforeExport: true }],
    '@babel/plugin-proposal-class-static-block',
    '@babel/plugin-proposal-class-properties',
    '@babel/plugin-proposal-do-expressions',
    '@babel/plugin-proposal-export-default-from',
    '@babel/plugin-proposal-export-namespace-from',
    '@babel/plugin-proposal-function-bind',
    '@babel/plugin-proposal-numeric-separator',
    ['@babel/plugin-proposal-pipeline-operator', { proposal: 'minimal' }],
    '@babel/plugin-proposal-throw-expressions',
    '@babel/plugin-syntax-module-string-names',
    '@babel/plugin-syntax-top-level-await' // top-level await
];
function babelPresetSweet(api, options = {}, dirname) {
    const { env, typescript, react } = options;
    const { nodeEnv, ecmascript, targets: customTargets, debug, modules, useBuiltIns } = env !== null && env !== void 0 ? env : {}, { use: useTypescript, isReact = true } = typescript !== null && typescript !== void 0 ? typescript : {}, { use: useReact = true, runtime, development } = react !== null && react !== void 0 ? react : {};
    const envModules = modules !== null && modules !== void 0 ? modules : false; // @babel/preset-env的模块类型
    const presets = [], plugins = [
        ...defaultPlugins,
        [
            '@babel/plugin-transform-runtime',
            {
                corejs: { version: 3, proposals: true },
                helpers: true,
                regenerator: nodeEnv || !ecmascript
            }
        ]
    ];
    // 添加@babel/preset-env
    if (!ecmascript) {
        const useBuiltInsValue = useBuiltIns !== null && useBuiltIns !== void 0 ? useBuiltIns : 'usage';
        const presetEnvOptions = {
            targets: customTargets !== null && customTargets !== void 0 ? customTargets : {
                browsers: nodeEnv ? ['node 10'] : [
                    'last 2 versions',
                    'last 10 Chrome versions',
                    'last 1 year',
                    'IE 11'
                ]
            },
            debug,
            modules: envModules,
            useBuiltIns: useBuiltInsValue,
            bugfixes: true
        };
        if (useBuiltInsValue) {
            presetEnvOptions.corejs = 3;
        }
        presets.push(['@babel/preset-env', presetEnvOptions]);
    }
    // 添加@babel/preset-react
    if (useReact) {
        presets.push([
            '@babel/preset-react',
            {
                runtime: runtime !== null && runtime !== void 0 ? runtime : (moduleExists('react/jsx-runtime') ? 'automatic' : 'classic'),
                development: development !== null && development !== void 0 ? development : isDevelopment
            }
        ]);
    }
    // 添加@babel/preset-typescript
    if (useTypescript) {
        presets.push([
            '@babel/preset-typescript',
            {
                isTSX: true,
                jsxPragma: isReact ? 'React' : 'Preserve',
                allExtensions: true,
                allowNamespaces: true
            }
        ]);
    }
    return { presets, plugins };
}
export default babelPresetSweet;
